@@ -1,6 +1,6 @@
 package Catalyst::Example::InstantCRUDStylish;
 
-$VERSION = '0.0368';
+$VERSION = '0.0369';
 
 use warnings;
 use strict;
@@ -15,25 +15,25 @@ __END__
 
 =head1 NAME
 
-Catalyst::Example::InstantCRUDStylish - A CRUD scaffolding for Catalyst 
+Catalyst::Example::InstantCRUDStylish - **EXPERIMENTAL** CRUD scaffolding for Catalyst
 *** (forked from Catalyst::Example::InstantCRUD) with some css style.
 
 =head1 VERSION
 
-This document describes Catalyst::Example::InstantCRUDStylish version 0.0368
+This document describes Catalyst::Example::InstantCRUDStylish version 0.0369
 
 =head1 SYNOPSIS
 
     instantcrudstylish.pl My::App -dsn='dbi:Pg:dbname=CE' -user=zby -password='pass'
 
 The L<instantcrudstylish.pl> executable creates a skeleton CRUD application in
-current directory. 
+current directory.
 
 =head1 DESCRIPTION
 
-The script will create CRUD interface (CReate, Update, Delete) 
+The script will create CRUD interface (CReate, Update, Delete)
 with paging and sort for all
-tables defined in the accessed database.  
+tables defined in the accessed database.
 The Create and Update forms let you manipulate also on relations
 (even many to many).
 
@@ -47,10 +47,10 @@ When the code is generated you can run the application:
 
 To access the CRUD interface to the tables you need to add
 '/tablename' (in lowercase) to the address:
-http://localhost:3000/tablename 
-(Note that if the table name has a underscore, that underscore should be 
-deleted in the address so table foo_bar is available at 
-http://localhost:3000/foobar, this is due to some conversions made by the 
+http://localhost:3000/tablename
+(Note that if the table name has a underscore, that underscore should be
+deleted in the address so table foo_bar is available at
+http://localhost:3000/foobar, this is due to some conversions made by the
 underlying libraries).
 
 The generated application will use DBIx::Class for model classes and
@@ -58,9 +58,9 @@ Template::Toolkit for View.
 
 =head1 WHY ANOTHER INSTANTCRUD ?
 
-The reason to release this is all about standards. 
-This is my attempt to standarize my control panels and applications 
-internals. 
+The reason to release this is all about standards.
+This is my attempt to standarize my control panels and applications
+internals.
 This InstantCRUD Stylished uses:
 blueprint for css standard
 modified thickbox with callback function for ajax modals
@@ -70,7 +70,7 @@ jquery for js
 
 =head1 HOW TO STYLE YOUR APP
 
-Download the Catalyst-Example-InstantCRUDStylish-0.0xx.tar.gz from CPAN. 
+Download the Catalyst-Example-InstantCRUDStylish-0.0xx.tar.gz from CPAN.
 Decompress that file and inside it, there is a .rar on the root.
 Then, use this instantcrudstylish to create your application dirs, and after that
 replace your app root dir with the 'root dir' inside .rar file.
@@ -82,10 +82,10 @@ The first place for customisations are the Template Toolkit templates
 and the CSS file.
 The CSS file used by the application is root/static/css/painel-de-controle.css.
 The templates are generated in directories named after the controllers in the
-root directory.  
+root directory.
 
-The generated controller is a subclass of 
-Catalyst::Example::Controller::InstantCRUDStylish. 
+The generated controller is a subclass of
+Catalyst::Example::Controller::InstantCRUDStylish.
 You can use the standard OO technique of overriding the documented methods
 to customize and extend it.
 The form handling code is in the controller.
@@ -95,12 +95,12 @@ See Makefile.PL
 
 =head1 RESOURCES
 
-L<http://dev.catalyst.perl.org/wiki/crud/instantcrudstylish> - InstantCRUDStylish page at 
+L<http://dev.catalyst.perl.org/wiki/crud/instantcrudstylish> - InstantCRUDStylish page at
 the Catalyst wiki.
 
 =head1 BUGS AND LIMITATIONS
- 
-This is still experimental and it is a first new release 
+
+This is still experimental and it is a first new release
 after a long time and substantial refactoring so treat with caution.
 
 The '0.04005' vesion of DBIx::Class::Schema::Loader does not
